function [C] = btex3_rbc(vb,length,...
  Cin,x_AtC,C_T,P1,Nseg,C,DT);

% FUNCTION BTEX3_RBC: Function simulates 3-region blood-tissue exchange
% model for oxygen transport in myocardium, described in
%   Beard, DA. integrated computational modeling of oxygen transport and 
%   cellular energetics explains observations on in vivo cardiac oxygen 
%   consumption and energy metabolites. PLoS Comput Biol (in press), 2006.
% 
% INPUTS:
% vb      blood velocity (microns per second)
% length  capillary length (microns)
% Cin     inflow total (dissolved + bound) oxygen con
% x_AtC   ATP consumption parameter
% C_T,P1  table of total oxygen concentration and pO2 in blood
% Nseg    number of segments to use in BTEX model
% C       initial state variable matrix (30 x Nseg)
% DT      time span (approximate) to simulate
%
% OUTPUTS:
% C       final matrix of state variables in cell region

% Time step for Lagrangian algorithm
dx = length/Nseg;
dt = dx/vb;

Nstep = round(DT/dt);
for i = 1:Nstep
    
% Advection:
  C(1,2:Nseg) = C(1,1:(Nseg-1));
  C(1,1) = Cin;
    
% Permeation and reaction
  for k = 1:Nseg
    [t,y] = ode15s(@cell_dCdT,[0 dt],C(:,k),[],C_T,P1,x_AtC);
    C(:,k) = y(end,:)';
  end

% This section of code makes a plot of the oxygen profiles and pauses
% the simulation. Comment this out to make the simulation not pause.
% BEGIN section on plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  CtO1 = C(1,:);    % total oxygen conc in capillary
  CtO2 = C(2,:);    % total oxygen conc in ISF
  CtO3 = C(3,:);    % total oxygen conc in cell
  a_1 = 1.30e-6;    % oxygen solubility in plasma
  a_2 = 1.25e-6;    % oxygen solubility in ISF
  a_3 = 1.74e-6;    % oxygen solubility in cell
  CMb = 200e-6;     % Myoglobin concentration 
  C50 = a_3*(2.39); % oxy-myoglobin 1/2 saturation
  PO2_1 = interp1(C_T,P1,CtO1,'linear');
  PO2_2 = CtO2/a_2;
  PO2_3 = (( CtO3-(C50+CMb) + sqrt( (CtO3-(C50+CMb)).^2 + 4*C50.*CtO3 ) )/2)/a_3;
  x = ((1:Nseg)-0.5)./Nseg; 
  figure(1); plot(x,PO2_1,x,PO2_2,x,PO2_3); axis([0 1 0 100]);
  legend('PO_2 (cap)','PO_2 (ISF)','PO_2 (cell)');
  xlabel('x/L'); ylabel('Oxygen partial pressure (mmHg)'); pause;
% END sectin on plotting %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  
end
